@@ -180,8 +180,6 @@ def find_unconserved_metabolites(model):
             " Solver status is '{}' (only optimal expected).".format(status))
 
 
-# FIXME: The results of this function are currently inconsistent with
-# published results.
 def find_inconsistent_min_stoichiometry(model, atol=1e-13):
     """
     Detect inconsistent minimal net stoichiometries.
@@ -219,11 +217,10 @@ def find_inconsistent_min_stoichiometry(model, atol=1e-13):
     metabolites = sorted(internal_mets, key=get_id)
     stoich, met_index, rxn_index = con_helpers.stoichiometry_matrix(
         metabolites, reactions)
-    left_ns = con_helpers.nullspace(stoich.T)
-    # deal with numerical instabilities
-    left_ns[np.abs(left_ns) < atol] = 0.0
-    LOGGER.info("nullspace has dimension %d", left_ns.shape[1])
-    inc_minimal = set()
+    left_ns = con_helpers.nullspace(stoich.T, atol)
+    if left_ns.size == 0:
+        LOGGER.info("Left nullspace is empty!")
+        return {(met,) for met in unconserved_mets}
     (problem, indicators) = con_helpers.create_milp_problem(
         left_ns, metabolites, Model, Variable, Constraint, Objective)
     # We clone the existing configuration in order to apply non-default
@@ -232,12 +229,17 @@ def find_inconsistent_min_stoichiometry(model, atol=1e-13):
         config=model.solver.configuration,
         problem=problem
     )
-    LOGGER.debug(str(problem))
+    LOGGER.info(
+        "Left nullspace has a dimension of %d.", left_ns.shape[1]
+    )
+    LOGGER.debug("%s", str(problem))
+    inc_minimal = set()
     cuts = list()
     for met in unconserved_mets:
+        # always add the met as an uncoserved set if there is no left nullspace
         row = met_index[met]
         if (left_ns[row] == 0.0).all():
-            LOGGER.debug("%s: singleton minimal unconservable set", met.id)
+            LOGGER.debug("%s: singleton minimal unconservable set.", met.id)
             # singleton set!
             inc_minimal.add((met,))
             continue
